==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Authentication timed out</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk is busy, cannot unmount now</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk is busy, cannot eject now</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>The device is busy, cannot eject now</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>The device is busy, cannot remove now</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>The device was not safely removed</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Click &quot;Safely Remove&quot; and then disconnect it next time</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">The device is busy, cannot eject now</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">The device is busy, cannot remove now</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Cannot unmount the device</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Cannot find the mounted device</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disks</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Eject all</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>The device has been safely removed</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Access denied</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>You do not have permission to access this folder</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Scanning the device, stop it?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.3.orig.tar.xz: dde-file-manager-5.8.3/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Authentication timed out</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk is busy, cannot unmount now</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk is busy, cannot eject now</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>The device is busy, cannot eject now</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>The device is busy, cannot remove now</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>The device was not safely removed</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Click &quot;Safely Remove&quot; and then disconnect it next time</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Cannot unmount the device</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Cannot find the mounted device</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disks</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Eject all</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>The device has been safely removed</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Access denied</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>You do not have permission to access this folder</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Scanning the device, stop it?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirm</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Stop</translation>
    </message>
</context>
</TS>
